@@ -275,8 +275,12 @@ the layout to the selected layout-name."
 	    (concat (riece-concat-channel-modes
 		     channel "Mode (? for help)") ": ")
 	    nil riece-minibuffer-map))))
-  (riece-send-string (format "MODE %s :%s\r\n" (riece-identity-prefix channel)
-			     change)))
+  (if (equal change "")
+      (riece-send-string (format "MODE %s\r\n"
+				 (riece-identity-prefix channel)))
+    (riece-send-string (format "MODE %s %s\r\n"
+			       (riece-identity-prefix channel)
+			       change))))
 
 (defun riece-command-set-operators (users &optional arg)
   (interactive
@@ -350,6 +354,7 @@ the layout to the selected layout-name."
 
 (defun riece-command-send-message (message notice)
   "Send MESSAGE to the current channel."
+  (run-hooks 'riece-command-send-message-hook)
   (if (equal message "")
       (error "No text to send"))
   (riece-check-channel-commands-are-usable)
@@ -393,11 +398,13 @@ the layout to the selected layout-name."
 (defun riece-command-enter-message-to-user (user)
   "Send the current line to USER."
   (interactive
-   (let ((completion-ignore-case t))
-     (list (riece-completing-read-identity
-	    "Message to user: "
-	    (riece-get-users-on-server (riece-current-server-name))
-	    nil nil nil nil nil t))))
+   (if (and (bolp) (eolp))
+       (error "No text to send")
+     (let ((completion-ignore-case t))
+       (list (riece-completing-read-identity
+	      "Message to user: "
+	      (riece-get-users-on-server (riece-current-server-name))
+	      nil nil nil nil nil t)))))
   (let ((text (buffer-substring
 	       (riece-line-beginning-position)
 	       (riece-line-end-position))))
@@ -620,8 +627,23 @@ If prefix argument ARG is non-nil, toggle frozen status."
   (interactive "sIRC command: ")
   (riece-send-string (concat command "\r\n")))
 
+(defun riece-command-beginning-of-buffer ()
+  "Scroll channel buffer to the beginning."
+  (interactive)
+  (let (buffer window)
+    (setq buffer (if riece-channel-buffer-mode
+		     riece-channel-buffer
+		   riece-dialogue-buffer))
+    (or (setq window (get-buffer-window buffer))
+	(setq window (get-buffer-window riece-dialogue-buffer)
+	      buffer riece-dialogue-buffer))
+    (when window
+      (save-selected-window
+	(select-window window)
+	(goto-char (point-min))))))
+
 (defun riece-command-end-of-buffer ()
-  "Get end of the dialogue buffer."
+  "Scroll channel buffer to the end."
   (interactive)
   (let (buffer window)
     (setq buffer (if riece-channel-buffer-mode
@@ -648,7 +670,7 @@ If prefix argument ARG is non-nil, toggle frozen status."
 			  (list (riece-format-identity user t)))
 			(riece-get-users-on-server
 			 (riece-current-server-name))))
-	 (current (current-word))
+	 (current (or (current-word) ""))
 	 (completion (try-completion current table))
 	 (all (all-completions current table)))
     (if (eq completion t)
@@ -660,7 +682,7 @@ If prefix argument ARG is non-nil, toggle frozen status."
 	      (display-completion-list all))
 	  (delete-region (point) (- (point) (length current)))
 	  (insert completion))))))
-  
+
 (defun riece-command-open-server (server-name)
   (interactive
    (list (completing-read "Open server: " riece-server-alist)))
